<?php
/**
 * @package WordPress
 * @subpackage WPExplorer Themes
*/

//main constants
define( 'WPEX_FRAMEWORK_DIR', get_template_directory_uri().'/framework' );
define( 'WPEX_JS_DIR', get_template_directory_uri().'/js' );
define( 'WPEX_CSS_DIR', get_template_directory_uri().'/css' );

/*--------------------------------------*/
/* Include core functions & framework <= Careful when editing here!
/*--------------------------------------*/

//post types & taxonomies
//register post types/taxonomies first for use in the framework
require_once('theme_functions/post_types.php');
require_once('theme_functions/taxonomies.php');

//core framework
require_once('framework/wpex_framework.php');

//admin options
require_once('theme_functions/admin_options.php');

//load css and js
require_once('theme_functions/scripts.php');
require_once('theme_functions/custom_css.php');

//widgets
require_once('theme_functions/widget_areas.php');

//load these functions only in the admin dashboard
if(defined('WP_ADMIN') && WP_ADMIN ) {
	
	//main functions
	require_once('theme_functions/meta_usage.php');
	require_once('theme_functions/editor_columns.php');	
	
}



/*--------------------------------------*/
/* Theme Setup
/*--------------------------------------*/

//content width
$content_width = 970; // Default width of primary content area

//menu walker
require_once('theme_functions/menu_walker.php');

//register navigation menus
register_nav_menus(
	array(
		'top_menu' => __('Top','wpex'),
		'main_menu' => __('Main','wpex'),
		'footer_menu' => __('Footer','wpex')
	)
);
		
//add image sizes
if(function_exists('add_image_size')) {
	add_image_size('full-size',  9999, 9999, false);
	add_image_size('small-thumb',  90, 90, true);
}
		
//localization support
load_theme_textdomain( 'wpex', get_template_directory() .'/lang' );

//posts per page
require_once('theme_functions/posts_per_page.php');


/*--------------------------------------*/
/* Other functions
/*--------------------------------------*/

//post excerpt length
function new_excerpt_length($length) {
	global $data;
	return $data['blog_excerpt'];
}
add_filter('excerpt_length', 'new_excerpt_length');

//replace excerpt link
function new_excerpt_more($more) {
	global $post;
	return '...';
}
add_filter('excerpt_more', 'new_excerpt_more');



/*--------------------------------------*/
/* Your Custom Functions
/* This lovely area has been saved for
/* You convinience.
/* Place your custom functions below
/*--------------------------------------*/


/*
//use this function to add more social icons to your theme
function add_social_icons($social_icons){
	
	//new icons
	$extra_social_icons = array(
		'New Sample Social Service'
	);
	
	//combine icons
	$social_icons = array_merge($extra_social_icons, $social_icons);
	
	//return new array with added icons
	return $social_icons;
	
}
add_filter('wpex_get_social', 'add_social_icons');
*/


?>