<?php
/**
 * @package WordPress
 * @subpackage WPExplorer Themes
 */
global $data; //get theme options
?>
<!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>

<meta http-equiv="Content-Type" content="<?php bloginfo('html_type'); ?>; charset=<?php bloginfo('charset'); ?>" />

<?php if($data['disable_responsive'] !='disable') { ?>
<!-- Mobile Specific
================================================== -->
<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1">
<!--[if lt IE 9]>
	<script src="http://css3-mediaqueries-js.googlecode.com/svn/trunk/css3-mediaqueries.js"></script>
<![endif]-->
<?php } ?>


<!-- Title Tag
================================================== -->
<title><?php wp_title(''); ?><?php if(wp_title('', false)) { echo ' |'; } ?> <?php bloginfo('name'); ?></title>

<?php if(!empty($data['custom_favicon'])) { ?>
<!-- Favicon
================================================== -->
<link rel="icon" type="image/png" href="<?php echo $data['custom_favicon']; ?>" />
<?php } ?>


<!-- Browser dependent stylesheets
================================================== -->

<!--[if IE 8]>
	<link rel="stylesheet" type="text/css" href="<?php echo get_template_directory_uri(); ?>/css/ie8.css" media="screen" />
<![endif]-->

<!--[if IE 7]>
	<link rel="stylesheet" type="text/css" href="<?php echo get_template_directory_uri(); ?>/css/ie7.css" media="screen" />
    <?php if($data['enable_icon_fonts'] !='disable'){ ?>
    	<link rel="stylesheet" type="text/css" href="<?php echo get_template_directory_uri(); ?>/css/awesome_font_ie7.css.css" media="screen" 	<?php } ?>
/>
<![endif]-->


<!-- Load HTML5 dependancies for IE
================================================== -->
<!--[if IE]>
	<script src="http://html5shiv.googlecode.com/svn/trunk/html5.js"></script><![endif]-->
<!--[if lte IE 7]>
	<script src="js/IE8.js" type="text/javascript"></script><![endif]-->
<!--[if lt IE 7]>
	<link rel="stylesheet" type="text/css" media="all" href="css/ie6.css"/>
<![endif]-->


<?php
//cutom fonts css
get_template_part( 'includes/custom-fonts');

//tracking code - header
echo stripslashes($data['tracking_header']);
?>

<!-- WP Head
================================================== -->
<?php wp_head(); ?>

</head><!-- /end head -->

<!-- Begin Body
================================================== -->
<body <?php body_class('body '. $data['color_scheme'] .''); ?>>

<?php if($data['disable_top_bar'] != 'disable') { ?>
    <div id="top-bar" <?php if($data['top_bar_position'] == 'fixed') { echo 'class="top-bar-fixed"'; } ?>>
        <div id="top-bar-inner" class="outerbox clearfix">
        	<?php
            //show top navigation unless disabled
			if($data['disable_top_bar_menu'] !='disable') { ?> 
                <nav id="top-navigation">
                    <?php wp_nav_menu( array(
                        'theme_location' => 'top_menu',
                        'menu_class' => 'top-menu sf-menu',
                        'sort_column' => 'menu_order',
                        'fallback_cb' => false,
                        'walker' => new wpex_menu_walker()
                    )); ?>
                </nav><!-- /top-bar-nav -->
            <?php }
			//top bar menu alternative
			if($data['disable_top_bar_menu'] == 'disable' && $data['top_bar_menu_alternative']) { ?>
                <div id="top-bar-left">
                    <?php echo do_shortcode($data['top_bar_menu_alternative']); ?>
                </div><!--top-bar-right -->
			<?php } ?>  
            
            <?php
            //show social region if not disabled
			if($data['enable_disable_social'] !='disable') { ?>
            <ul id="social">
                <?php
                $social_links = wpex_get_social();
                //social loop
                foreach($social_links as $social_link) {
                    if(!empty($data[$social_link])) {
                        echo '<li><a href="'. $data[$social_link] .'" title="'. $social_link .'" target="_blank"><img src="'. get_template_directory_uri() .'/images/social/'.$social_link.'.png" alt="'. $social_link .'" /></a></li>';
                } }
                ?>
            </ul><!-- /social -->
            <?php } ?>
			<?php
			//show social alternative
			if($data['enable_disable_social'] == 'disable' && $data['social_alternative']) { ?>
                <div id="top-bar-right">
                    <?php echo do_shortcode($data['social_alternative']); ?>
                </div><!--top-bar-right -->
			<?php } ?>
        </div><!-- /top-bar-inner -->
    </div><!-- /top-bar -->
<?php } ?>

<header id="header" class="outerbox clearfix <?php if($data['top_bar_position'] == 'fixed' && $data['disable_top_bar'] !='disable') { echo 'header-extra-margin'; } ?>">

    <div id="logo">
        <?php if($data['custom_logo']) { ?>
            <a href="<?php echo home_url(); ?>/" title="<?php get_bloginfo( 'name' ); ?>" rel="home"><img src="<?php if ($data['custom_logo'] == '' ) { echo get_template_directory_uri() . '/images/logo.png'; } else { echo $data['custom_logo']; } ?>" alt="<?php get_bloginfo( 'name' ) ?>" /></a>
        <?php } else { ?>
        	 <a href="<?php echo home_url(); ?>/" title="<?php get_bloginfo( 'name' ); ?>" rel="home"><h2><?php echo get_bloginfo( 'name' ); ?></h2></a>
        <?php } ?>
    </div><!-- /logo -->
    
    <div id="header-right">
   		<?php
		//above search
        if($data['above_search']) { ?>
    	<div id="search-above">
        	<?php echo do_shortcode($data['above_search']); ?>
        </div><!-- /search-above -->
        <?php } ?>
		<?php
		//search bar
        if($data['enable_disable_search'] != 'disable') { ?>
        <div id="top-search">
            <?php get_search_form(); ?>
        </div><!-- /top-search -->
        <?php } ?>
        <?php
        //below search
        if($data['below_search']) { ?>
		<div id="search-below">
        	<?php echo do_shortcode($data['below_search']); ?>
        </div><!-- /search-above -->
        <?php } ?>
    </div><!-- /header-right -->
    
</header><!-- /header -->

<div id="wrap" class="outerbox clearfix">

    <nav id="navigation" class="clearfix">
        <?php wp_nav_menu( array(
            'theme_location' => 'main_menu',
            'sort_column' => 'menu_order',
            'menu_class' => 'sf-menu',
            'fallback_cb' => false,
			'walker' => new wpex_menu_walker()
        )); ?>
    </nav><!-- /navigation -->  
    
	<div id="main-content" class="clearfix fitvids-container">
    
	<?php
	//run code only on pages
	if(is_page() && !is_attachment()) {
		
		//show large featured images on pages
		$full_img = wp_get_attachment_image_src(get_post_thumbnail_id(), 'full-size');
		if($full_img) { echo '<div id="page-featured-img"><img src="'. $full_img[0] .'" alt="'. get_the_title() .'" /></div>'; }
		
		//show sliders if selected
		global $post;
		$page_slider = get_post_meta($post->ID, 'wpex_page_slider', TRUE); //get slider meta
		
		if($page_slider != 'no_slider' && $page_slider != '') { ?>
			<div id="full-slider"><?php echo do_shortcode("[slider id=".$page_slider."]"); ?></div><!--/full-slider -->
		<?php }
	}
	?>