<?php
/**
 * @package WordPress
 * @subpackage WPExplorer Themes
 */
 
//get theme options
global $data;

//get header
get_header();

//start post loop
if (have_posts()) : while (have_posts()) : the_post();

//get meta
$portfolio_video = get_post_meta($post->ID, 'wpex_portfolio_video', TRUE);
$portfolio_type = get_post_meta($post->ID, 'wpex_portfolio_type', TRUE);
$portfolio_featured_image = get_post_meta($post->ID, 'wpex_portfolio_featured_image', TRUE);
$portfolio_slider_image = get_post_meta($post->ID, 'wpex_portfolio_slider_image', TRUE);
$portfolio_meta = get_post_meta($post->ID, 'wpex_portfolio_meta', TRUE);
$portfolio_post_style = get_post_meta($post->ID, 'wpex_portfolio_post_style', TRUE);

//get terms
$terms = get_the_term_list( get_the_ID(), 'portfolio_cats' );
?>

<header id="page-heading">
	<h1><?php the_title(); ?></h1>
	<nav id="single-nav" class="clearfix"> 
        <?php next_post_link('<div id="single-nav-left">%link</div>', '<span class="inner"><span class="wpex-icon-chevron-left"></span></span>', false); ?>
        <?php previous_post_link('<div id="single-nav-right">%link</div>', '<span class="inner"><span class="wpex-icon-chevron-right"></span></span>', false); ?>
    </nav><!-- /single-nav -->
</header><!-- /page-heading -->

<article <?php if($portfolio_post_style != 'full') { ?>id="post"<?php } ?> class="single-portfolio clearfix"> 

	<?php
	//show portfolio meta if not disabled
	if($portfolio_meta !='disable') { ?>
	<section id="single-meta" class="meta clearfix" >
        <ul>
           <li><span class="wpex-icon-calendar"></span><?php the_date(); ?></li>
           <?php if($terms) { ?><li><span class="wpex-icon-folder-open"></span><?php echo get_the_term_list( get_the_ID(), 'portfolio_cats', '', ', ', ' ') ?></li><?php } ?>
           <?php if($data['enable_disable_portfolio_comments'] !='disable' && comments_open()) { ?><li class="comment-scroll"><span class="wpex-icon-comment"></span><?php wpex_translation('comments'); ?></li><?php } ?>
        </ul>
	</section><!-- /meta -->
    <?php } ?>
    
    <?php
	//show media region if featured image or slider aren't disabled
	if($portfolio_slider_image != 'disable' || $portfolio_featured_image != 'disable') { ?>
        <div id="single-portfolio-media">
        
            <?php
            //show featured image if not disabled
            if($portfolio_featured_image != 'disable') {
                
            //get featured image url
            $thumb = get_post_thumbnail_id();
            $img_url = wp_get_attachment_url($thumb,'full'); //get full URL to image
                
            //image height
            ($data['portfolio_image_height']) ? $featured_image_height = 400 * str_replace('%', '', $data['portfolio_image_height']) / 100 : $featured_image_height = 400;
            
            //image widht
            ($portfolio_post_style == 'full') ? $featured_image_width = '920' : $featured_image_width = '640';
            
            //resize & crop the featured image
            ($data['enable_disable_single_portfolio_image_crop'] == 'enable') ? $featured_image = aq_resize( $img_url, $featured_image_width, $featured_image_height, true ) : $featured_image = aq_resize( $img_url, 640, 9999, false );
            
            if($featured_image) {
            ?>
                <div class="post-thumbnail">
                    <a href="<?php echo $img_url; ?>" title="<?php the_title(); ?>" class="prettyphoto-link">
                        <img src="<?php echo $featured_image; ?>" alt="<?php echo the_title(); ?>" />
                    </a>
                </div><!-- /post-thumbnail -->
            <?php
                } //no featured image
            }//featured image disabled
            ?>
            
            <?php
            //show slider unless disabled
            if($portfolio_slider_image != 'disable') { ?>
            <div id="portfolio-slides-wrap">
                <?php echo do_shortcode("[slider id=".$post->ID."]"); ?>
            </div><!-- /portfolio-slides-wrap -->
            <?php } ?>
        </div><!-- /single-portfolio-media -->
    <?php } ?>
    
    <article id="single-portfolio-info" class="entry clearfix">
        <?php the_content(); ?>
    </article><!-- /single-portfolio-info -->
    
	<?php
	//show related posts unless disabled
    if($data['enable_disable_portfolio_related_posts'] !='disable') {
		
		//get single post disable option
		$portfolio_related_posts = get_post_meta($post->ID, 'wpex_portfolio_related_posts', TRUE);
		
		//show if not disabled in admin
		if($portfolio_related_posts != 'disable') {
		
		//get related portfolio posts
		$cats = wp_get_post_terms($post->ID, 'portfolio_cats');
		
		//don't even bother if there aren't any portfolio categories
		if($cats) {  ?>
		<div id="single-portfolio-related" class="clearfix">
					<h3 class="heading"><span><?php echo $data['translation_related_items'] ? $data['translation_related_items'] : __('Related Items','wpex'); ?></span></h3>
			<div class="grid-container">
				<?php
				//grid style
				$portfolio_grid_image_height = 300;
				$portfolio_grid_style = $data['portfolio_related_grid']; //get grid style meta
				$portfolio_grid_class = wpex_grid($portfolio_grid_style); //set grid style
	
				//loop arguments
				$args = array(
					'post__not_in' => array( $post->ID ),
					'orderby'=> 'post_date',
					'order' => 'rand',
					'post_type' => 'portfolio',
					'posts_per_page' => $data['portfolio_related_count'],
					'tax_query' => array(
						'relation' => 'OR',
						array(
							'taxonomy' => 'portfolio_cats',
							'terms' => $cats[0]->term_id
						),
					)
				);
				$my_query = new WP_Query($args);
				if( $my_query->have_posts() ) {
				while ($my_query->have_posts()) : $my_query->the_post();
					//get the portfolio loop style
					get_template_part('includes/loop','portfolio');
				endwhile; wp_reset_query(); } ?>
			</div><!--/grid-container -->
		</div><!-- /single-portfolio-related -->
    <?php
    		} //no cats
		} //disabled in meta
	} //disable in admin
	?>
    
	<?php if($data['enable_disable_portfolio_comments'] !='disable') { comments_template(); } //show comments if not disabled ?>
    
</article><!-- /post -->
  
<?php
//end post loop
endwhile; endif;

//get sidebar only on default portfolio style
if($portfolio_post_style != 'full') {
	get_sidebar('portfolio');
}

//get template footer
get_footer(); ?>