<?php
/**
 * @package WordPress
 * @subpackage WPExplorer Themes
 */
 
//get theme options
global $data;

//get template header
get_header();

//start post loop
if (have_posts()) : while (have_posts()) : the_post();

//get meta options
$single_featured_image = get_post_meta($post->ID, 'wpex_single_featured_image', TRUE);
$single_single_tags = get_post_meta($post->ID, 'wpex_single_tags', TRUE);
$single_author_bio = get_post_meta($post->ID, 'wpex_single_author_bio', TRUE);
$single_related_posts = get_post_meta($post->ID, 'wpex_single_related_posts', TRUE);

//image height
($data['post_image_height']) ? $post_image_height = 400 * str_replace('%', '', $data['post_image_height']) / 100 : $post_image_height = 400;
?>

<header id="page-heading">
	<h1><?php the_title(); ?></h1>
	<nav id="single-nav" class="clearfix"> 
        <?php next_post_link('<div id="single-nav-left">%link</div>', '<span class="inner"><span class="wpex-icon-chevron-left"></span></span>', false); ?>
        <?php previous_post_link('<div id="single-nav-right">%link</div>', '<span class="inner"><span class="wpex-icon-chevron-right"></span></span>', false); ?>
    </nav><!-- /single-nav --> 
</header><!-- /post-meta -->

<div id="post" class="clearfix">

    	<?php 
        //show only on non-protected posts
		if(!post_password_required()) : ?>
        
        <?php
        //show post meta if not disabled
		if($data['enable_disable_single_meta'] !='disable') { ?>
            <section class="meta clearfix" id="single-meta">
                <ul>
                    <li><span class="wpex-icon-calendar"></span><?php the_date(); ?></li>    
                    <li><span class="wpex-icon-folder-open"></span><?php the_category(' / '); ?></li>
                    <li class="comment-scroll"><span class="wpex-icon-comment"></span><?php wpex_translation('comments'); ?></li>
                    <li><span class="wpex-icon-user"></span><?php the_author_posts_link(); ?></li>
               </ul>
            </section><!--/meta -->
        <?php } ?>
        
        <?php
		//show if not disabled in admin
		if($single_featured_image != 'disable') {
			
		//featured image
		$thumb = get_post_thumbnail_id();
		$img_url = wp_get_attachment_url($thumb,'full'); //get full URL to image
		($data['enable_disable_single_post_image_crop'] == 'enable') ? $featured_image = aq_resize( $img_url, 640, $post_image_height, true ) : $featured_image = $img_url;
		
		if($data['enable_disable_post_image'] !='disable' && $featured_image) {
		?>
		<div id="post-thumbnail">
			<a href="<?php echo $img_url; ?>" title="<?php the_title(); ?>" class="prettyphoto-link">
            	<img src="<?php echo $featured_image; ?>" alt="<?php echo the_title(); ?>" />
            </a>
		</div><!-- /post-thumbnail -->
        <?php } } ?>
        
        <?php
		endif; //end password required test ?>
        
		<article class="entry clearfix">
			<?php the_content(); // *** this is your main post content output *** ?>
        </article><!-- /entry -->
        
		<?php 
        //show only on non-protected posts
		if(!post_password_required()) : ?>
        
        <?php wp_link_pages(' '); ?>
        
		<?php
		//show tags unless disabled
        if($single_single_tags !='disable' && $data['enable_disable_single_tags'] !='disable') {
			the_tags('<div class="post-tags clearfix"><h4 class="heading"><span>'. wpex_translation('tags').'</span></h4>','','</div>');
		}
		?>
        
		<?php
        //show author bio unless disabled
        if($single_author_bio != 'disable' && $data['enable_disable_single_author_bio'] !='disable') { ?>
        <div id="single-author" class="clearfix">
            <h3 class="heading"><span><?php echo $data['translation_author'] ? $data['translation_author'] : __('Author Bio','wpex'); ?></span></h3>
            <div id="author-image">
                <a href="<?php the_author_meta('user_url'); ?>"><?php echo get_avatar( get_the_author_meta('user_email'), '60', '' ); ?></a>
            </div><!-- author-image --> 
            <div id="author-bio">
                <h4><?php the_author_link(); ?></h4>
                <p><?php the_author_meta('description'); ?></p>
            </div><!-- author-bio -->
        </div><!-- /single-author -->
        <?php } ?>
        
		<?php
        //show related posts unless disabled
        if($single_related_posts != 'disable' && $data['enable_disable_single_related_posts'] !='disable') {
    
        //start related posts section
        $category = get_the_category(); //get first current category ID
        $this_post = $post->ID; // get ID of current post
        
        $args = array(
            'numberposts' => '3',
            'orderby' => 'rand',
            'category' =>  $category[0]->cat_ID,
            'exclude' => $this_post,
            'offset' => null
        );
        $posts = get_posts($args);
        if($posts) { ?>
            <section id="related-posts" class="boxframe">
                <h3 class="heading"><span><?php echo $data['translation_related_articles'] ? $data['translation_related_articles'] : __('Related Articles','wpex'); ?></span></h3>
                <?php
                foreach($posts as $post) : setup_postdata($post);
			  	//featured img
				$thumb = get_post_thumbnail_id();
				$img_url = wp_get_attachment_url($thumb,'full'); //get full URL to image
				$featured_image = aq_resize( $img_url, 150, 120, true ); //resize & crop the image
                ?>
                <div class="related-entry clearfix">
                    <?php if($featured_image) { ?>
                         <a href="<?php the_permalink() ?>" title="<?php the_title(); ?>" class="alignleft blog-entry-img-link">
                         	<img class="related-post-image blog-entry-img" src="<?php echo $featured_image; ?>" alt="<?php echo the_title(); ?>" />
                         </a>
                    <?php } ?>
                    <div class="related-entry-content">
                      <h4><a href="<?php the_permalink(); ?>"><?php the_title()?></a></h4>
                      <div class="related-entry-excerpt">
                        <?php echo wp_trim_words( get_the_content(), 25, '...' ); ?><a href="<?php the_permalink(); ?>" class="read-more"><?php _e('read more','wpex'); ?> &rarr;</a>
                      </div><!-- /related-entry-excerpt -->
                    </div>
                    <!-- /related-entry-content -->
                </div>
                <!-- /related-entry -->
                <?php endforeach; wp_reset_postdata(); ?>
            </section> 
            <!-- /related-posts --> 
            <?php } } ?>
            
            <?php
			endif; //end password required test ?>
        
        <?php
        //show comments if not disabled
        if($data['enable_disable_blog_comments'] !='disable') { comments_template(); } ?>
        
</div><!-- /post -->

<?php
//end post loop
endwhile; endif;

//get template sidebar
get_sidebar();

//get template footer
get_footer(); ?>