<?php
/**
 * Custom CSS For wp_head Hook = wpex_custom_css()
*/

//it would be silly to run this large function in the admin.
if (! is_admin()) {
	
	//hook function
	add_action('wp_head', 'wpex_custom_css');
	
	//begin function
	function wpex_custom_css() {
	
		//get global vars for use in this function
		global $data, $post;
		
		$custom_css ='';
		
		/**custom css field**/
		if($data['custom_css']) {
			$custom_css .= $data['custom_css'];
		}
	
		/* body backgrounds */
		
		//define vars to prevent debug errors
		$single_custom_bg_url = $single_custom_bg_style = $single_custom_bg_color = '';
		
		//get single meta background option
		if(is_single() || is_page()) {
			$single_custom_bg_url = get_post_meta($post->ID, 'wpex_single_custom_bg_url', TRUE);
			$single_custom_bg_style = get_post_meta($post->ID, 'wpex_single_custom_bg_style', TRUE);
			$single_custom_bg_color = get_post_meta($post->ID, 'wpex_single_custom_bg_color', TRUE);
		}
		
		//output only meta background option
		if($single_custom_bg_url) {
		
			$custom_css .= ($single_custom_bg_style == 'full') ? 'body{background: url('.$single_custom_bg_url.') no-repeat center center fixed; -webkit-background-size: cover;-moz-background-size: cover;-o-background-size: cover;background-size: cover}' : 'body{background-image: url('.$single_custom_bg_url.'); background-repeat; '.$single_custom_bg_style.' }';
		
		} elseif($single_custom_bg_color && $single_custom_bg_color !='#') {
			
			//background color
			$custom_css .= 'body{background-color:'.$single_custom_bg_color.'}';
			
		} else { //output admin options
		
			//setup background options array
			$custom_bg_options = array('main','portfolio','services','faqs','staff','blog');
			
			//loop through each background option
			foreach($custom_bg_options as $custom_bg_option) {
				
				//don't do anything is this section is disabled
				$data['main_enable_disable_custom_bg'] = 'enable'; //set dummy var for body
				
				if($data[''.$custom_bg_option.'_enable_disable_custom_bg'] !='disable') {
						
					//background option
					if($data[''.$custom_bg_option.'_bg'] || $data[''.$custom_bg_option.'_bg_custom']) {
						
					//specific classes based on post_types
					if($custom_bg_option == 'portfolio') {
						
						//portfolio body classes
						$custom_bg_classes = 'body.single-portfolio, body.page-template-template-portfolio-with-filter-php, body.page-template-template-portfolio-php, body.page-template-template-portfolio-sidebar-php, body.page-template-template-portfolio-filter-sidebar-php, body.tax-portfolio_cats';
						
					
					}elseif ($custom_bg_option == 'services') {
						
						//service body classes
						$custom_bg_classes = 'body.single-services, body.page-template-template-services-php, body.tax-services_cats';
						
					} elseif ($custom_bg_option == 'faqs') {
						
						//faqs body calsses
						$custom_bg_classes = 'body.single-faqs, body.page-template-template-faqs-php, body.tax-faqs_cats';
					
					} elseif ($custom_bg_option == 'staff') {
						
						//staff body calsses
						$custom_bg_classes = 'body.single-staff, body.page-template-template-staff-php, body.page-template-template-staff-sidebar-php, body.tax-staff_cats';
							
					} elseif ($custom_bg_option == 'blog') {
						
						//blog body calsses
						$custom_bg_classes = 'body.page-template-template-blog-php, body.single, body.archive';
						
					} else {
						//no body classes
						$custom_bg_classes = 'body';
					}
						
					//if pattern is not set to none or if custom background option isnt empty
					if($data[''.$custom_bg_option.'_bg'] !=''.get_template_directory_uri().'/images/bg/none.png' || $data[''.$custom_bg_option.'_bg_custom'] !='') {
						
						//set default bg
						$custom_bg_image = ($data[''.$custom_bg_option.'_bg_custom']) ? $data[''.$custom_bg_option.'_bg_custom'] : $data[''.$custom_bg_option.'_bg'];
						
						
						//full style background
						if($data[''.$custom_bg_option.'_bg_style'] == 'full') {
							$custom_css .= $custom_bg_classes.'{background: url('.$custom_bg_image.') no-repeat center center fixed;-webkit-background-size:cover;-moz-background-size:cover;-o-background-size: cover;background-size: cover}';
						
						} else {
							
							//regular background
							$custom_css .= $custom_bg_classes.'{background-image: url('.$custom_bg_image.'); background-repeat: '.$data[''.$custom_bg_option.'_bg_style'].'; -webkit-background-size: auto;-moz-background-size: auto;-o-background-size: auto;background-size: auto;}';
						}
					} else {
						//no background
						$custom_css .= $custom_bg_classes.'{background-image: none}';
						}
					}
					
					//color options
					if($data[''.$custom_bg_option.'_bg_color']) {
						$custom_css .= $custom_bg_classes .'{background-color: '.$data[''.$custom_bg_option.'_bg_color'].'}';
					}
				
				} //custom bg disabled
				
			} //end loop
			
		} //end meta check
		
		
		/*container background colors*/
		
		
		//array of areas that have background color options
		$custom_bg_containers = array();
		
		//loop through containers and apply background from admin option
		foreach($custom_bg_containers as $custom_bg_container) {
			
			//retrieve background option for containers (in the admin set the option with an id such as header_bg)
			$custom_bg = $data[''.$custom_bg_container.'_bg'];
			
			//output css
			if($custom_bg){
				$custom_css .= '.'. $custom_bg_container .'{background-color: '.$custom_bg.'}';
			}
		
		}
		
		
		/* main */
		
		//header
		if($data['header_logo_top_margin'] && $data['header_logo_top_margin']!='0px') {
			$custom_css .= '#logo{margin-top: '.$data['header_logo_top_margin'].';}';
		}
		if($data['header_right_top_margin'] && $data['header_right_top_margin']!='0px') {
			$custom_css .= '#header-right{margin-top: '.$data['header_right_top_margin'].';}';
		}
		
		//sidebar location
		if($data['sidebar_position'] == 'left') {
			$custom_css .= '#sidebar {float: left} #post{float: right}';
		}
		
		
		/* hovers */
		
		//containers with hovers
		$custom_overlay_containers = array('portfolio', 'staff', 'blog');
		
		
		//loop through containers and apply background from admin option
		foreach($custom_overlay_containers as $custom_overlay_container) {
			
			//retrieve background option for containers (in the admin set the option with an id such as header_bg)
			$custom_overlay_color = $data[''.$custom_overlay_container.'_overlay_color'];
			$custom_overlay_opacity = $data[''.$custom_overlay_container.'_overlay_opacity'];
			
			//output color css
			if($custom_overlay_color){
				$custom_css .= 'body .'. $custom_overlay_container .'-entry-img-link:hover{background: '.$custom_overlay_color.'}';
			}
			
			//output opacity css
			if($custom_overlay_opacity){
				$custom_css .= 'body .'. $custom_overlay_container .'-entry-img:hover{opacity: '.$custom_overlay_opacity.'; -webkit-opacity: '.$custom_overlay_opacity.'; -moz-opacity: '.$custom_overlay_opacity.'}';
			}
			
		
		}
		
		
		/* Fonts */
		
		//font Variables
		$body_font = $data['body_font'];
		$headings_font = $data['headings_font'];
		$navigation_font = $data['navigation_font'];
		$tagline_font = $data['tagline_font'];
		
		//font face-types
		if($body_font['face'] && $body_font['face'] != 'default'){
			$custom_css .= 'body{font-family: '.$body_font['face'].';}';
		}	
			
		if($headings_font['face'] && $headings_font['face'] != 'default'){
			$custom_css .= 'h1,h2,h3,h4,h5,h6{font-family: '.$headings_font['face'].' !important;}';
		}
		
		if($tagline_font['face'] && $tagline_font['face'] != 'default'){
			$custom_css .= '#home-tagline{font-family: '.$tagline_font['face'].' !important;}';
		}
		
		if($navigation_font['face'] && $navigation_font['face'] != 'default'){
			$custom_css .= '#navigation, #top-bar {font-family: '.$navigation_font['face'].' !important;}';
		}
		
		//font weights
		if($body_font['style'] == 'italic'){
			$custom_css .= 'body{font-style: italic; font-weight: normal;}';
		}
		if($body_font['style'] == 'bold'){
			$custom_css .= 'body{font-weight: bold;}';
		}
		if($body_font['style'] == 'bold italic'){
			$custom_css .= 'body{font-weight: bold;font-style: italic;}';
		}
		
		if($headings_font['style'] == 'normal'){
			$custom_css .= 'h1,h2,h3,h4,h5,h6{font-weight: normal;}';
		}
		if($headings_font['style'] == 'italic'){
			$custom_css .= 'h1,h2,h3,h4,h5,h6{font-style: italic; font-weight: nomal;}';
		}
		if($headings_font['style'] == 'bold italic'){
			$custom_css .= 'h1,h2,h3,h4,h5,h6{font-weight: bold;font-style: italic;}';
		}
		
		if($navigation_font['style'] == 'italic'){
			$custom_css .= '#navigation,#navigation a{font-style: italic; font-weight: normal;}';
		}
		if($navigation_font['style'] == 'normal'){
			$custom_css .= '#navigation, #navigation a{font-weight: normal;}';
		}
		if($navigation_font['style'] == 'bold italic'){
			$custom_css .= '#navigation, #navigation a{font-weight: bold;font-style: italic;}';
		}
	
		if($tagline_font['style'] == 'italic'){
			$custom_css .= '#home-tagline{font-style: italic; font-weight: normal;}';
		}
		if($tagline_font['style'] == 'bold'){
			$custom_css .= '#home-tagline{font-weight: bold;}';
		}
		if($tagline_font['style'] == 'bold italic'){
			$custom_css .= '#home-tagline{font-weight: bold;font-style: italic;}';
		}
		
		//font sizes
		if($navigation_font['size'] != '13px'){
			$custom_css .= '#navigation, #navigation a{font-size: '.$navigation_font['size'].';}';
		}
		
		if($tagline_font['size'] != '28px'){
			$custom_css .= '#home-tagline{font-size: '.$tagline_font['size'].';}';
		}
		
		//custom font css
		if($data['custom_font_css']){
			$custom_css .= $data['custom_font_css'];
		}
		
		/**echo all css**/
		$css_output = "<!-- Custom CSS -->\n<style type=\"text/css\">\n" . $custom_css . "\n</style>";
		
		if(!empty($custom_css)) {
			echo $css_output;
		}
		
	} //end wpex_custom_css()

} //is admin
?>